# Composite recommenders

***Based on "SparseMatrixRecommender" and "LatentSemanticAnalyzer"***

## Introduction

This package has functions and classes for the creation and utilization 
of composite recommenders.

-------

## Usage examples

- `LSAEndowedSMR` : ["LSAEndowedSMR-recommend-by-profile-and-text.py"](./examples/LSAEndowedSMR-recommend-by-profile-and-text.py)

-------

## References

[AAp1] Anton Antonov,
[SparseMatrixRecommender Python package](https://pypi.org/project/SparseMatrixRecommender/),
(2021),
[PyPI.org/antononcube](https://pypi.org/user/antononcube/).

[AAp2] Anton Antonov,
[LatentSemanticAnalyzer Python package](https://pypi.org/project/LatentSemanticAnalyzer/),
(2021),
[PyPI.org/antononcube](https://pypi.org/user/antononcube/).